ChinaDNS
========

A DNS forwarder that ignores incorrect(you know it) responses.

ChinaDNS creates a DNS server at localhost.

Install
-------

OS X:
^^^^^

::

    pip install .
    pip install chinadns

Windows:
^^^^^^^^

::

    easy_install pip
    pip install chinadns

Debian / Ubuntu:
^^^^^^^^^^^^^^^^

::

    apt-get install python-pip
    pip install chinadns

CentOS:
^^^^^^^

::

    yum install python-setuptools
    easy_install pip
    pip install shadowdns

Usage
-----

Run ``sudo chinadns`` on your local machine.

Set your DNS to 127.0.0.1.

License
-------

MIT

Bugs and Issues
---------------

Please visit `Issue
Tracker <https://github.com/clowwindy/ChinaDNS/issues?state=open>`__

Mailing list: http://groups.google.com/group/shadowsocks
